/* Programme de dmonstration de la liaison srie
 
	Fichier 		: lcd.h

	Compilateur 	: MPLAB C18
	date 			: 14/02/2006
 	Auteur			: Philippe Lucidarme (philippe.lucidarme@univ-angers.fr)
	Cible 			: PIC18F452 
   	Carte			: CNC Micro
	Quartz			: 20 MHz
 	
	Rsum			: Bibliothque permettant l'utilisation de l'cran LCD sur le bus ic
					
	
	Description		: 

*/

#include "I2Clib.h"
#include <delays.h>
#include <stdlib.h>

#define LCD_CURSOR_ON		1
#define LCD_CURSOR_OFF		0
#define LCD_BACKLIGHT_ON	1
#define LCD_BACKLIGHT_OFF	0

#define AdrLCD				0x00


//*********************** Prototypes des fonctions ************************/

unsigned char LCDClear		(void); 							// Efface l'cran LCD
unsigned char LCDCursor		(unsigned char statut); 			// Change l'tat du curseur
unsigned char LCDBackLight	(unsigned char statut); 			// Change l'tat du rtro clairage
unsigned char LCDPutChar	(char carac);			 			// Affiche un caractre sur l'cran
unsigned char LCDGotoXY		(unsigned char x,unsigned char y);	// Place le curseur aux coordonnes x,y
unsigned char LCDPutText	(const rom char* text);				// Affiche une chane de caractres
unsigned char LCDPutInt		(int num);							// Affiche un entier


//************************** Code des fonctions ***************************/

// Efface l'cran LCD
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDClear	(void)
{
	if (SendI2C (AdrLCD,0x1B)) return (1);	// Envoie le caractre 0x1B
	if (SendI2C (AdrLCD,0x43)) return (1);	// Envoie le caractre 0x43	
	Delay1KTCYx(75);						// Attente de 15ms
	return (0);
}

// Change l'tat du curseur
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDCursor		(unsigned char statut)
{
	if (SendI2C (AdrLCD,0x1B)) return (1);	// Envoie le caractre 0x1B
	if (statut)
	{	// Cursor ON
		if (SendI2C (AdrLCD,0x53)) return (1);	// Envoie le caractre 0x42	
	}
	else
	{	// Cursor OFF
		if (SendI2C (AdrLCD,0x73)) return (1);	// Envoie le caractre 0x43	
	}
	return (0);
}

// Change l'tat du curseur
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDBackLight	(unsigned char statut)
{
	if (SendI2C (AdrLCD,0x1B)) return (1);	// Envoie le caractre 0x1B
	if (statut)
	{	// Cursor ON
		if (SendI2C (AdrLCD,0x42)) return (1);	// Envoie le caractre 0x42	
	}
	else
	{	// Cursor OFF
		if (SendI2C (AdrLCD,0x62)) return (1);	// Envoie le caractre 0x43	
	}
	return (0);
}



// Affiche un caractre sur l'cran
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDPutChar	(char carac)
{
	if (SendI2C (AdrLCD,carac)) return (1);
	return (0);
}


// Place le curseur aux coordonnes x,y
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDGotoXY	(unsigned char x,unsigned char y)
{
	if (SendI2C (AdrLCD,0x1B)) 	return (1);	// Envoie le caractre 0x1B
	if (SendI2C (AdrLCD,0x4C)) 	return (1);	// Envoie le caractre 0x43	
	if (SendI2C (AdrLCD,x)) 	return (1);	// Envoie le caractre 0x1B
	if (SendI2C (AdrLCD,y)) 	return (1);	// Envoie le caractre 0x43	
		
	Delay10TCYx(200);						// Attente de 100 s
	return (0);
}

// Affiche une chane de caractres
// Retourne 1 en cas de problme
// Retourne 0 si tout s'est bien pass
unsigned char LCDPutText (const rom char* text)
{
	unsigned char i=0;
	while (text[i]!=0)	
		if (LCDPutChar(text[i++])) return 1;
	return (0);
}

// Affiche un entier
unsigned char LCDPutInt	(int num)
{
	unsigned char i=0;
	char text[7];
	
	itoa (num,text);		
	while (text[i]!=0)	
		if (LCDPutChar(text[i++])) return 1;
	return (0);
}
